#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['formula1py', 'formula1py.tests']

package_data = \
{'': ['*']}

install_requires = \
['requests >=2.20']

setup(name='formula1py',
      version='0.8.0',
      description='Python package that wraps Ergast F1 API',
      author='Alex Raskin',
      author_email='alexraskin@fastmail.fm',
      url='https://github.com/alexraskin/f1py',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      python_requires='>=3.7',
     )
